terraform {
  required_providers {
    vsphere = {
      source = "hashicorp/vsphere"
      version = "2.0.0"
    }
  }
  backend "http" {}
}

# Vsphere provider config

variable "vsphere_user" {
  description = "Administrator user"
  type        = string
  sensitive   = false
}

variable "vsphere_password" {
  description = "Administrator password"
  type        = string
  sensitive   = true
}

provider "vsphere" {
  user           = var.vsphere_user
  password       = var.vsphere_password
  vsphere_server = "horizont.sch.bme.hu"

  allow_unverified_ssl = true
}

data "vsphere_datacenter" "DC" {
  name = "NOC"
}

data "vsphere_datastore" "NOC-A-Storage" {
  name          = "NOC-A-Test-Storage1"
  datacenter_id = data.vsphere_datacenter.DC.id
}

data "vsphere_datastore" "NOC-B-Storage" {
  name          = "NOC-B-Test-Storage1"
  datacenter_id = data.vsphere_datacenter.DC.id
}

data "vsphere_resource_pool" "NOC-A" {
  name          = "noc-a-test.internal/Resources"
  datacenter_id = data.vsphere_datacenter.DC.id
}

data "vsphere_resource_pool" "NOC-B" {
  name          = "noc-b-test.internal/Resources"
  datacenter_id = data.vsphere_datacenter.DC.id
}